Skip to contents

Add and remove source notes. Source notes are like footnotes, except that they are not linked to a cell in the table and carry no marker. They are printed below the footnotes, after the abbreviations note.

Usage

modify_source_note(x, source_note, text_interpret = c("md", "html", "none"))

remove_source_note(x, source_note_id = NULL)

Arguments

x

(ltsummary)
An ltsummary object.

source_note

(string)
A string to add as a source note.

text_interpret

(string)
How the text is interpreted: "md" (the default; the markdown subset **bold**, _italic_ and line breaks), "html" (raw HTML) or "none" (shown verbatim).

source_note_id

(integer)
The ids of the source notes to remove. Source notes are numbered in the order they were added. Default is NULL, which removes all source notes.

Value

An ltsummary object.

Examples

# Example 1 ----------------------------------
tbl <- tbl_summary(trial, include = c(marker, grade), missing = "no") |>
  modify_source_note("Results as of June 26, 2015")
tbl
# Example 2 ---------------------------------- remove_source_note(tbl, source_note_id = 1)