Returns the function that computes the statistics of a model for
add_glance_table() and add_glance_source_note(): a base-R function
with the columns of broom::glance() for lm, glm and coxph models,
and broom::glance() itself for other classes (broom must then be
installed). To report other statistics, pass a function to the
glance_fun argument of those functions instead.
See also
Other regression tables:
add_glance_table(),
add_global_p(),
add_n_regression,
add_nevent(),
add_significance_stars(),
add_vif(),
combine_terms(),
global_pvalue_fun(),
tbl_regression(),
tbl_uvregression()