The default anova_fun of add_global_p(). For every term of the model
formula it tests that all the term's coefficients are zero, with the
statistic car::Anova() uses for the model class: an F test for lm, a
likelihood-ratio test for glm and coxph. Other model classes use a
Wald chi-square test from vcov().
Arguments
- x
(regression model)
A fitted model.- type
(
string)"III"(the default) tests each term with every other term kept in the model;"II"tests each term that can be dropped while respecting marginality, withstats::drop1().- ...
Not used.
See also
Other regression tables:
add_glance_table(),
add_global_p(),
add_n_regression,
add_nevent(),
add_significance_stars(),
add_vif(),
combine_terms(),
glance_fun_s3(),
tbl_regression(),
tbl_uvregression()
Examples
global_pvalue_fun(glm(response ~ age + grade, trial, family = binomial))
#> term df statistic p.value
#> 1 age 1 0.02458829 0.8753973
#> 2 grade 2 3.72205767 0.1555126